package com.bootdo.datas.controller;


import com.bootdo.common.annotation.Log;
import com.bootdo.common.utils.PageUtils;
import com.bootdo.common.utils.Query;
import com.bootdo.common.utils.R;

import com.bootdo.common.utils.StringUtils;
import com.bootdo.datas.dto.GyDataImportDTO;
import com.bootdo.datas.service.GyDataService;

import com.google.common.collect.Lists;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@Controller
@RequestMapping("/datas/dataSendProvince")
public class DataSendProvinceController {

    private static Logger log = LoggerFactory.getLogger(DataSendProvinceController.class);

    @Autowired
    private GyDataService gyDataService;

    @GetMapping()
    @Log("访问送审省级")
    @RequiresPermissions("datas:dataSendProvince:data")
    String Data() {
        return "datas/dataSendProvince/data";
    }

    @ResponseBody
    @GetMapping("/list")
    @RequiresPermissions("datas:dataSendProvince:data")
    public PageUtils list(@RequestParam Map<String, Object> params) {
        // 查询列表数据
        Query query = new Query(params);
        query.put("dataStatusArrs", Lists.newArrayList(3));
        query.put("auditStageMenu", "1");
        query.put("neqDataStatus", "4");

        List<GyDataImportDTO> dataList = gyDataService.list(query);
        int total = gyDataService.countTotal(query);
        PageUtils pageUtils = new PageUtils(dataList, total);
        return pageUtils;
    }


    @GetMapping("/edit/{id}")
    @RequiresPermissions("datas:dataSendProvince:edit")
    String edit(@PathVariable("id") Long id, Model model) {
        GyDataImportDTO data = gyDataService.get(id);
        model.addAttribute("data", data);
        return "datas/dataSendProvince/edit";
    }


    /**
     * @Description: 送审
     */
    @PostMapping("/sendVerify")
    @ResponseBody
    @RequiresPermissions("datas:dataSendProvince:sendVerify")
    public R sendVerify(@RequestParam("ids[]") Long[] ids) {
        log.info("送审 ids:" + ids.toString());
        for (Long id : ids) {
            log.info("送审 id:" + id);
            GyDataImportDTO data = new GyDataImportDTO();
            // 判断是否已审核过
            data = gyDataService.get(id);
            // 送审状态 0 未送审 1 送审 2 专家审核
            log.info("status:" + data.getSendVerify());
            if (!"0".equals(data.getSendVerify())
                    && "1".equals(data.getAuditStage())
                    && "3".equals(data.getDataStatus())) {
                data.setId(id);
                data.setSendVerify("0");// 0 未送审 1 送审 2 专家审核
                // 0:待审核 1:删除 2:审核中 3:通过审核 4:驳回
                data.setDataStatus("0");
                data.setAuditStage("2");
                gyDataService.updateStatus(data);
            }
        }
        return R.ok();
    }



}
